package services

import (
	"encoding/json"
	"fmt"
	"hongze/hongqi_watch/global"
	"hongze/hongqi_watch/utils"
	"io/ioutil"
	"net/http"
	"strings"
)

type BaseResponse struct {
	Ret         int
	Msg         string
	ErrMsg      string
	ErrCode     string
	Data        interface{}
	Success     bool `description:"true 执行成功，false 执行失败"`
	IsSendEmail bool `json:"-" description:"true 发送邮件，false 不发送邮件"`
	IsAddLog    bool `json:"-" description:"true 新增操作日志，false 不新增操作日志" `
}

// postRefreshEdbData 刷新指标数据
func postRefreshEdbData(param map[string]interface{}, urlStr string) (resp *BaseResponse, err error) {
	postUrl := global.CONFIG.Serve.EdbLibUrl + urlStr
	postData, err := json.Marshal(param)
	if err != nil {
		return
	}
	result, err := HttpPost(postUrl, string(postData), "application/json")
	if err != nil {
		return
	}
	if result != nil {
		global.LOG.Info(" Refresh Result: " + string(result))
		err = json.Unmarshal(result, &resp)
		if err != nil {
			return
		}
		return resp, nil
	}
	return nil, err
}

func HttpPost(url, postData string, params ...string) ([]byte, error) {
	body := ioutil.NopCloser(strings.NewReader(postData))
	client := &http.Client{}
	req, err := http.NewRequest("POST", url, body)
	if err != nil {
		return nil, err
	}
	contentType := "application/x-www-form-urlencoded;charset=utf-8"
	if len(params) > 0 && params[0] != "" {
		contentType = params[0]
	}
	req.Header.Set("Content-Type", contentType)
	req.Header.Set("authorization", utils.MD5(global.CONFIG.Serve.AppEdbLibNameEn+global.CONFIG.Serve.EdbLibMd5Key))
	resp, err := client.Do(req)
	if resp != nil {
		defer resp.Body.Close()
		b, err := ioutil.ReadAll(resp.Body)
		fmt.Println("HttpPost:" + string(b))
		return b, err
	}
	return nil, err
}

// 调用指标库公共服务处理卓创红期指标
func HandleHqExcelDataByEdbLib(indexDataList []*SciHqExcel) (resp *BaseResponse, err error) {
	urlStr := "sci_hq/handle/excel_data"
	postUrl := global.CONFIG.Serve.EdbLibUrl + urlStr
	postData, err := json.Marshal(indexDataList)
	if err != nil {
		return
	}
	result, err := HttpPost(postUrl, string(postData), "application/json")
	if err != nil {
		return
	}
	if result != nil {
		global.LOG.Info(" Refresh Result: " + string(result))
		err = json.Unmarshal(result, &resp)
		if err != nil {
			return
		}
		return resp, nil
	}
	return
}
